<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package lettery
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<!-- comments -->
<div class="mil-gray-bg">
	<div class="container">
		<div class="row justify-content-center">

			<div class="col-lg-12 col-xl-7 mil-appearance mil-p-120-120">
				<div id="comments" class="post-comments">

				<?php
				// You can start editing here -- including this comment!
				if ( have_comments() ) :
				?>

				<div class="mil-group-title mil-mb-30">
					<h4><?php comments_number( esc_html__( 'No comments found', 'lettery' ), esc_html__( '1 Comment', 'lettery' ), esc_html__( '% Comments', 'lettery' ) ); ?></h4>
				</div>

				<!-- comments -->
				<ul class="mil-comments-list">
					<?php
					wp_list_comments( array(
						'style'	  => 'ul',
						'avatar_size' => '80',
						'callback' => 'lettery_comment'
					) );
					?>
				</ul>

				<?php
				the_comments_navigation( array(
					'screen_reader_text' => ' ',
					'prev_text' => esc_html__( 'Older comments', 'lettery' ),
					'next_text' => esc_html__( 'Newer comments', 'lettery' )
				) );

				// If comments are closed and there are comments, let's leave a little note, shall we?
				if ( ! comments_open() ) :
				?>
				<p class="mil-text no-comments"><?php esc_html_e( 'Comments are closed.', 'lettery' ); ?></p>
				<?php endif; ?>

				<?php endif; // Check for have_comments().
				?>

				<div class="form-comment <?php if ( comments_open() ) : ?>form-comment-open<?php endif; ?>">
					<?php
						$req = get_option( 'require_name_email' );
						$aria_req = ( $req ? " aria-required='true'" : '' );

						$comment_args = array(
							'title_reply' => esc_html__( 'Write a comment', 'lettery' ),
							'title_reply_to' => esc_html__( 'Write a comment to %s', 'lettery' ),
							'cancel_reply_link' => esc_html__( 'Cancel Reply', 'lettery' ),
							'title_reply_before' => '<div id="reply-title" class="title comment-reply-title"><h4 class="mil-mb-30">',
							'title_reply_after' => '</h4></div>',
							'label_submit' => esc_html__( 'Submit', 'lettery' ),
							'comment_field' => '<div class="mil-group-input mil-mb-30"><textarea placeholder="' . esc_attr__( 'Comment', 'lettery' ).'" id="comment" name="comment" aria-required="true" ></textarea></div>',
							'must_log_in' => '<p class="mil-text mil-mb-30 must-log-in">' . esc_html__( 'You must be ', 'lettery' ) . '<a href="' . esc_url( wp_login_url( apply_filters( 'the_permalink', get_permalink( ) ) ) ) . '">' . esc_html__( 'logged in', 'lettery' ) . '</a>' . esc_html__( ' to post a comment.', 'lettery' ) . '</p>',
							'logged_in_as' => '<p class="mil-text mil-mb-30 logged-in-as">' . esc_html__( 'Logged in as ', 'lettery' ) . '<a href="' . esc_url( admin_url( 'profile.php' ) ) . '">' . esc_html( $user_identity ) . '</a>' . esc_html__( '. ', 'lettery' ) . '<a href="' . esc_url( wp_logout_url( apply_filters( 'the_permalink', get_permalink( ) ) ) ) . '" title="' . esc_attr__( 'Log out of this account', 'lettery' ) . '">' . esc_html__( 'Log out?', 'lettery' ) . '</a></p>',
							'comment_notes_before' => '',
							'comment_notes_after' => '',
							'fields' => apply_filters( 'comment_form_default_fields', array(
								'author' => '<div class="mil-group-input"><input id="author" name="author" type="text" placeholder="' . esc_attr__( 'Name', 'lettery' ) . '" value="" ' . $aria_req . ' /></div>',
								'email' => '<div class="mil-group-input"><input id="email" name="email" type="text" placeholder="' . esc_attr__( 'Email', 'lettery' ) . '" value="" ' . $aria_req . ' /></div>',
							)),
							'class_submit' => 'mil-button mil-button-lg mil-button mil-button-lg-text',
							'submit_field' => '<div class="form-comment-submit">%1$s %2$s</div>',
							'submit_button' => '<button type="submit" name="%1$s" id="%2$s" class="%3$s"><span>%4$s</span></button>'
						);

						comment_form( $comment_args );
					?>
				</div>

				</div>
			</div>

		</div>
	</div>
</div>
<!-- comments end -->
