<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package lettery
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function lettery_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	$header_template = get_field( 'header_template', 'option' );

	if ( empty( $header_template ) ) {
		$classes[] = 'mil-default';
	}

	$smooth_scroll_enable = get_field( 'smooth_scroll_enable', 'option' );

	if ( !empty( $smooth_scroll_enable ) ) {
		$classes[] = 'mil-scrollbar';
	}

	return $classes;
}
add_filter( 'body_class', 'lettery_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function lettery_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'lettery_pingback_header' );
