<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package lettery
 */

if ( ! function_exists( 'lettery_after_content' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function lettery_after_content() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'lettery' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'lettery' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( '', 'list item separator', 'lettery' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tags-links">' . esc_html__( 'Tags: %1$s', 'lettery' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'lettery' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}

		// Show share buttons in blog post and portfolio
		if ( function_exists( 'lettery_add_social_share' ) ) :
			echo lettery_add_social_share( get_the_ID() );
		endif;

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'lettery' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'lettery_after_title' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function lettery_after_title() {
		$categories_list = get_the_category( get_the_ID() );
		?>
		<div class="mil-post-info mil-appearance mil-center mil-mb-30">
			<div class="mil-author">
				<img src="<?php echo esc_url( get_avatar_url( get_current_user_id(), ['size' => '40'] ) ); ?>" alt="<?php echo esc_attr( get_the_author() ); ?>" />
				<span class="mil-dark mil-link"><?php echo esc_html( get_the_author() ); ?></span>
			</div>
			<?php if ( $categories_list ) : ?>
			<span class="mil-dot-divider mil-link mil-accent">&#x2022;</span>
			<?php foreach ( $categories_list as $index => $category ) : ?>
			<span class="mil-accent mil-link"><?php echo esc_html( $category->cat_name ); ?></span>
			<?php break; endforeach; ?>
			<?php endif; ?>
			<span class="mil-dot-divider mil-link mil-accent">&#x2022;</span>
			<span class="mil-link mil-softened-30"><?php echo esc_html( get_the_date() ); ?></span>
		</div>
		<?php
	}
endif;

if ( ! function_exists( 'lettery_single_navigantion' ) ) :
	/**
	 * Displays an optional prev/next/all nagigations.
	 */
	function lettery_single_navigantion() {
		if ( is_singular() ) :

			$prev_post = get_adjacent_post( false, '', true );
			$next_post = get_adjacent_post( false, '', false );
			$archive_url = false;
			$archive_page_id = get_field( get_post_type() . '_page', 'option' );
			if ( ! $archive_page_id ) {
				$archive_url = get_post_type_archive_link( get_post_type() );
			} else {
				$archive_url = get_permalink( $archive_page_id );
			}

			$prev_str = esc_html__( 'Previous', 'lettery' );
			$next_str = esc_html__( 'Next', 'lettery' );
			$all_str = esc_html__( 'All posts', 'lettery' );

			?>

	    <!-- navigation -->
	    <div class="mil-post-navigation">
	      <?php if ( is_a( $prev_post, 'WP_Post' ) ) : ?>
	      <!-- button -->
	      <a href="<?php echo esc_url( get_permalink( $prev_post->ID ) ); ?>" class="mil-link">
					<i class="fas fa-chevron-left"></i>
					<span><?php echo esc_html( $prev_str ); ?></span>
				</a>
				<?php else : ?>
				<span class="mil-link">
					<i class="fas fa-chevron-left"></i>
					<span><?php echo esc_html( $prev_str ); ?></span>
				</span>
				<?php endif; ?>
				<?php if ( $archive_url ) : ?>
	      <div class="mil-post-navigation-center mil-m-hidden">
	        <a class="mil-link" href="<?php echo esc_url( $archive_url ); ?>"><?php echo esc_html( $all_str ); ?></a>
	      </div>
	      <?php endif; ?>
	      <?php if ( is_a( $next_post, 'WP_Post' ) ) : ?>
	      <!-- button -->
	      <a href="<?php echo esc_url( get_permalink( $next_post->ID ) ); ?>" class="mil-link">
					<span><?php echo esc_html( $next_str ); ?></span>
					<i class="fas fa-chevron-right"></i>
				</a>
				<?php else : ?>
				<span class="mil-link">
					<span><?php echo esc_html( $next_str ); ?></span>
					<i class="fas fa-chevron-right"></i>
				</span>
				<?php endif; ?>
	    </div>
	    <!-- projects navigation end -->

		<?php
		endif; // End is_singular().
	}
endif;
